| DataSpaceGroups | R Documentation |
An R6 class for DataSpace Groups data.
DataSpaceConnection$getGroups()
DataSpaceConnection -> DataSpaceGroups
availableDatasetsA data.table of datasets available in the object.
datasetsA list of data.table objects containing the availableDatasets that were loaded.
variableDefinitionsA data.table of variable definitions.
DataSpaceConnection$downloadPublicationData()DataSpaceConnection$filterMabGrid()DataSpaceConnection$getDaash()DataSpaceConnection$getDonors()DataSpaceConnection$getGroup()DataSpaceConnection$getGroups()DataSpaceConnection$getMab()DataSpaceConnection$getMabs()DataSpaceConnection$getStudies()DataSpaceConnection$getStudy()DataSpaceConnection$loadLanlMabMetadata()DataSpaceConnection$resetMabGrid()DataSpaceGroups$new()Initialize 'DataSpaceGroups' class.
See DataSpaceConnection.
DataSpaceGroups$new(groupIds = NULL)
groupIdsA character vecotor of 'group_id' values. as URL, path and username.
DataSpaceGroups$print()Print DataSpaceStudy class.
DataSpaceGroups$print()
DataSpaceGroups$refresh()Refresh loaded integrated datasets, and information of what datasets are available.
DataSpaceGroups$refresh()
DataSpaceGroups$clone()The objects of this class are cloneable with this method.
DataSpaceGroups$clone(deep = FALSE)
deepWhether to make a deep clone.
connectDS DataSpaceConnection
## Not run:
# Create a connection (Initiate a DataSpaceConnection object)
con <- connectDS()
# Get group by `group_id` or pass a filtered `availableGroups` object.
groups <- con$getGroups(c(266, 267))
groups <- con$availableGroups[label == "NYVAC durability comparison"] |>
con$getGroups()
# Retrieving group assay data for cvd408 from
# DataSpace is done automatically when the groups object is created.
groups$datasets$BAMA
# Get variable information of the assay dataset
groups$datasetDescription$BAMA
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.