checkNetrc: Check netrc file

View source: R/netrc.R

checkNetrcR Documentation

Check netrc file

Description

Check that there is a netrc file with a valid entry for the CAVD DataSpace.

Usage

checkNetrc(netrcFile = getNetrcPath(), onStaging = FALSE, verbose = TRUE)

Arguments

netrcFile

A character. File path to netrc file to check.

onStaging

A logical. Whether to check the staging server instead of the production server.

verbose

A logical. Whether to print the extra details for troubleshooting.

Value

The name of the netrc file

See Also

connectDS writeNetrc

Examples

## Not run: 
checkNetrc()

## End(Not run)

DataSpaceR documentation built on Aug. 27, 2026, 1:06 a.m.