An R6 class for DataSpace browsing and fetching data in DataSpace.
Active bindings
configA list. Stores configuration of the connection object such as URL, path and username.
availableStudiesA data.tabl of available studies.
availableGroupsA data.table of available groups.
availableMabsA data.table of available mAbs.
availableMabMixturesA data.table. Metadata of available mAb mixtures.
availableDonorsA data.table. Metadata about all mAb donors in the DataSpace.
availableVirusesA data.table of metadata about all virsues in the DataSpace and virus name synonyms.
availablePublicationsA data.table of available publications metadata and available datasets.
virusNameMappingTablesA list of data.tables containing virus name mappings.
mabGridSummaryDefunct. Use `availableMabs`.
mabGridDefunct. Use `availableMabs`.
virusMetadataDefunct. Use `virusNameMappingTables`.
Methods
Method new()
Initialize a DataSpaceConnection object.
See connectDS.
Usage
DataSpaceConnection$new(
login = NULL,
password = NULL,
verbose = FALSE,
onStaging = FALSE
)Arguments
loginA character. Optional argument. If there is no netrc file a temporary one can be written by passing login and password of an active DataSpace account.
passwordA character. Optional. The password for the selected login.
verboseA logical. Whether to print the extra details for troubleshooting.
onStagingA logical. Whether to connect to the staging server instead of the production server.
Method getMabs()
Create a `DataSpaceMabs` object.
Arguments
availableMabsan `availableMabs` or `availableMabMixtures` object, or a vector of `mab id` values. `mab_id` values are inferred from `availableMabMixtures` objects.
includeMixturesWhether or not to include mab mixtures. "yes", "no", or "only" are valid. The default, "yes", will return any available mAb mixtures for any mAb passed here.
Method downloadPublicationData()
Download study related publication datasets.
Usage
DataSpaceConnection$downloadPublicationData(
availablePublications = NULL,
downloadDir = tempdir()
)Examples
if (FALSE) { # \dontrun{
# Create a connection (Initiate a DataSpaceConnection object)
con <- connectDS()
# View available data
con$availableStudies
con$availableGroups
con$availablePublications
con$availableMabs
con$availableMabMixtures
con$availableDonors
con$availableViruses
# Pass an available object to a "get" method to get data
cvd408 <- con$availableStudies[study_id == "cvd408"] |>
con$getStudies()
cd4Mabs <- con$availableMabs[grepl("CD4bs", mab_ab_binding_type)] |>
con$getMabs()
} # }