An R6 class for DataSpace DAASH data.
Super class
DataSpaceR::DataSpaceConnection -> DataSpaceDaash
Active bindings
mabMetadataA data.table of mAbs with metadata found in the object.
donorMetadataA data.table of donors with metadata found in the object.
daashMetadataA data.table showing the donor and mAb metadata with CDS sequence_id values for the loaded DAASH dataset.
availableStructuresA data.table showing the mAb structures available to download.
datasetsA list of DAASH datastets loaded to the DAASH object.
variableDefinitionsA data.table of variable definitions.
Methods
Inherited methods
DataSpaceR::DataSpaceConnection$downloadPublicationData()DataSpaceR::DataSpaceConnection$filterMabGrid()DataSpaceR::DataSpaceConnection$getDaash()DataSpaceR::DataSpaceConnection$getDonors()DataSpaceR::DataSpaceConnection$getGroup()DataSpaceR::DataSpaceConnection$getGroups()DataSpaceR::DataSpaceConnection$getMab()DataSpaceR::DataSpaceConnection$getMabs()DataSpaceR::DataSpaceConnection$getStudies()DataSpaceR::DataSpaceConnection$getStudy()DataSpaceR::DataSpaceConnection$resetMabGrid()
Method new()
Initialize DataSpaceMabMetadata object.
See DataSpaceConnection.
Usage
DataSpaceDaash$new(availableDaash)Method getFastaFromSequences()
Return a fasta file for available daash sequences that have been loaded to the current object.
Usage
DataSpaceDaash$getFastaFromSequences(
sequenceType = "nt",
originalHeaders = FALSE,
path = NULL
)Arguments
sequenceTypecharacter the type of fasta file to return: nt = nucleotide, aa = amino acid.
originalHeadersboolean if the original fasta headers should be provided
pathThe path where to save the fasta files to. If using the default value, NULL, then a fasta file is returned as a character vector.
Method downloadAntibodyStructures()
Saves all antibody structures associated with the daash object's `availableStuctures` object.
Usage
DataSpaceDaash$downloadAntibodyStructures(path = tempdir(), mab_id = NULL)Examples
if (FALSE) { # \dontrun{
# Create a connection (Initiate a DataSpaceConnection object)
con <- connectDS()
# Get the daash object using either an availableMabs or
# availableDonors object.
daash <- con$availableMabs[mab_ab_binding_type %like% "CD4"] |>
con$getDaash()
# To get lineage sequences, query donors, then pipe available
# donors to the connection getDaash object.
daash <- con$availableDonors[
lineage_sequences_available == TRUE & mab_count < 10,
] |>
con$getDaash()
# Inspect what datasets are available
names(daash$datasets)
# Inspect the `topCalls` dataset
daash$datasets$topCalls
} # }