| DataSpaceDaash | R Documentation |
An R6 class for DataSpace DAASH data.
DataSpaceConnection$getDaash()
DataSpaceConnection -> DataSpaceDaash
mabMetadataA data.table of mAbs with metadata found in the object.
donorMetadataA data.table of donors with metadata found in the object.
daashMetadataA data.table showing the donor and mAb metadata with CDS sequence_id values for the loaded DAASH dataset.
availableStructuresA data.table showing the mAb structures available to download.
datasetsA list of DAASH datastets loaded to the DAASH object.
variableDefinitionsA data.table of variable definitions.
DataSpaceConnection$downloadPublicationData()DataSpaceConnection$filterMabGrid()DataSpaceConnection$getDaash()DataSpaceConnection$getDonors()DataSpaceConnection$getGroup()DataSpaceConnection$getGroups()DataSpaceConnection$getMab()DataSpaceConnection$getMabs()DataSpaceConnection$getStudies()DataSpaceConnection$getStudy()DataSpaceConnection$loadLanlMabMetadata()DataSpaceConnection$resetMabGrid()DataSpaceDaash$new()Initialize DataSpaceMabMetadata object.
See DataSpaceConnection.
DataSpaceDaash$new(availableDaash)
availableDaashavailableDaash an 'availableMabs', or 'availableDonors' object, or a vector of 'sequnce_id' values.
configA list.
DataSpaceDaash$print()Print the DataSpaceMab object summary.
DataSpaceDaash$print()
DataSpaceDaash$getFastaFromSequences()Return a fasta file for available daash sequences that have been loaded to the current object.
DataSpaceDaash$getFastaFromSequences( sequenceType = "nt", originalHeaders = FALSE, path = NULL )
sequenceTypecharacter the type of fasta file to return: nt = nucleotide, aa = amino acid.
originalHeadersboolean if the original fasta headers should be provided
pathThe path where to save the fasta files to. If using the default value, NULL, then a fasta file is returned as a character vector.
DataSpaceDaash$downloadAntibodyStructures()Saves all antibody structures associated with the daash object's 'availableStuctures' object.
DataSpaceDaash$downloadAntibodyStructures(path = tempdir(), mab_id = NULL)
pathThe directory to export fasta files to.
mab_idA subset of mab_ids to export. If using the default, NULL, all structures in availableStuctures are downloaded.
DataSpaceDaash$refresh()Refresh the DataSpaceMabMetadata object to update datasets.
DataSpaceDaash$refresh()
DataSpaceDaash$clone()The objects of this class are cloneable with this method.
DataSpaceDaash$clone(deep = FALSE)
deepWhether to make a deep clone.
connectDS DataSpaceConnection
## Not run:
# Create a connection (Initiate a DataSpaceConnection object)
con <- connectDS()
# Get the daash object using either an availableMabs or
# availableDonors object.
daash <- con$availableMabs[mab_ab_binding_type %like% "CD4"] |>
con$getDaash()
# To get lineage sequences, query donors, then pipe available
# donors to the connection getDaash object.
daash <- con$availableDonors[
lineage_sequences_available == TRUE & mab_count < 10,
] |>
con$getDaash()
# Inspect what datasets are available
names(daash$datasets)
# Inspect the `topCalls` dataset
daash$datasets$topCalls
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.