| DataSpaceMabs | R Documentation |
An R6 class for DataSpace MAb data.
DataSpaceConnection$getMab()
DataSpaceConnection -> DataSpaceMabs
mabMetadataA data.table of mAbs with metadata found in the object.
donorMetadataA data.table of donors with metadata found in the object.
mabMixMetadataA data.table. A table of mAb mixtures with metadata found in this DataSpaceMab instance.
mabMixA data.table. A mapping table of mab_mix_id to mab_id. with metadata found in this DataSpaceMab instance.
datasetsA list of data.table objects containing the mab related that were loaded.
variableDefinitionsA data.table of variable definitions.
DataSpaceConnection$downloadPublicationData()DataSpaceConnection$filterMabGrid()DataSpaceConnection$getDaash()DataSpaceConnection$getDonors()DataSpaceConnection$getGroup()DataSpaceConnection$getGroups()DataSpaceConnection$getMab()DataSpaceConnection$getMabs()DataSpaceConnection$getStudies()DataSpaceConnection$getStudy()DataSpaceConnection$loadLanlMabMetadata()DataSpaceConnection$resetMabGrid()DataSpaceMabs$new()Initialize DataSpaceMab object.
See DataSpaceConnection.
DataSpaceMabs$new(mabIds, includeMixtures)
mabIdsA character vector of 'mab_id' values.
includeMixturesWhether or not to include mab mixtures. "yes", "no", or "only" are valid.
DataSpaceMabs$print()Print the DataSpaceMab object summary.
DataSpaceMabs$print()
DataSpaceMabs$loadDaash()Load any available DAASH datasets.
DataSpaceMabs$loadDaash()
DataSpaceMabs$refresh()Refresh the DataSpaceMab object to update datasets.
DataSpaceMabs$refresh()
DataSpaceMabs$clone()The objects of this class are cloneable with this method.
DataSpaceMabs$clone(deep = FALSE)
deepWhether to make a deep clone.
connectDS DataSpaceConnection
## Not run:
# Create a connection (Initiate a DataSpaceConnection object)
con <- connectDS()
# Inspect available mabs, then pass subset to the `getMabs` method.
vrc01 <- con$availableMabs[mab_name_std == "VRC01"] |>
con$getMabs()
# Inspect the `NABMAb` assay data.
vrc01$datasets$NABMAb
# Load DAASH data from mab object
vrc01$loadDaash()
# Inspect DAASH datasets
vrc01$datasets$daash |> names()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.