Check that there is a netrc file with a valid entry for the CAVD DataSpace.
Usage
checkNetrc(netrcFile = getNetrcPath(), onStaging = FALSE, verbose = TRUE)Check that there is a netrc file with a valid entry for the CAVD DataSpace.
checkNetrc(netrcFile = getNetrcPath(), onStaging = FALSE, verbose = TRUE)